@@ -12,12 +12,16 @@ geom_label <- function(mapping = NULL, data = NULL,
                        label.padding = unit(0.25, "lines"),
                        label.r = unit(0.15, "lines"),
                        label.size = 0.25,
+                       size.unit = "mm",
                        na.rm = FALSE,
                        show.legend = NA,
                        inherit.aes = TRUE) {
   if (!missing(nudge_x) || !missing(nudge_y)) {
     if (!missing(position)) {
-      abort("You must specify either `position` or `nudge_x`/`nudge_y`.")
+      cli::cli_abort(c(
+        "Both {.arg position} and {.arg nudge_x}/{.arg nudge_y} are supplied.",
+        "i" = "Choose one approach to alter the position."
+      ))
     }
 
     position <- position_nudge(nudge_x, nudge_y)
@@ -31,11 +35,12 @@ geom_label <- function(mapping = NULL, data = NULL,
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
-    params = list(
+    params = list2(
       parse = parse,
       label.padding = label.padding,
       label.r = label.r,
       label.size = label.size,
+      size.unit = size.unit,
       na.rm = na.rm,
       ...
     )
@@ -60,20 +65,22 @@ GeomLabel <- ggproto("GeomLabel", Geom,
                         na.rm = FALSE,
                         label.padding = unit(0.25, "lines"),
                         label.r = unit(0.15, "lines"),
-                        label.size = 0.25) {
+                        label.size = 0.25,
+                        size.unit = "mm") {
     lab <- data$label
     if (parse) {
       lab <- parse_safe(as.character(lab))
     }
 
     data <- coord$transform(data, panel_params)
-    if (is.character(data$vjust)) {
-      data$vjust <- compute_just(data$vjust, data$y)
-    }
-    if (is.character(data$hjust)) {
-      data$hjust <- compute_just(data$hjust, data$x)
+    data$vjust <- compute_just(data$vjust, data$y, data$x, data$angle)
+    data$hjust <- compute_just(data$hjust, data$x, data$y, data$angle)
+    if (!inherits(label.padding, "margin")) {
+      label.padding <- rep(label.padding, length.out = 4)
     }
 
+    size.unit <- resolve_text_unit(size.unit)
+
     grobs <- lapply(1:nrow(data), function(i) {
       row <- data[i, , drop = FALSE]
       labelGrob(lab[i],
@@ -82,16 +89,17 @@ GeomLabel <- ggproto("GeomLabel", Geom,
         just = c(row$hjust, row$vjust),
         padding = label.padding,
         r = label.r,
+        angle = row$angle,
         text.gp = gpar(
           col = row$colour,
-          fontsize = row$size * .pt,
+          fontsize = row$size * size.unit,
           fontfamily = row$family,
           fontface = row$fontface,
           lineheight = row$lineheight
         ),
         rect.gp = gpar(
           col = if (isTRUE(all.equal(label.size, 0))) NA else row$colour,
-          fill = alpha(row$fill, row$alpha),
+          fill = fill_alpha(row$fill, row$alpha),
           lwd = label.size * .pt
         )
       )
@@ -106,11 +114,11 @@ GeomLabel <- ggproto("GeomLabel", Geom,
 
 labelGrob <- function(label, x = unit(0.5, "npc"), y = unit(0.5, "npc"),
                       just = "center", padding = unit(0.25, "lines"), r = unit(0.1, "snpc"),
-                      default.units = "npc", name = NULL,
+                      angle = NULL, default.units = "npc", name = NULL,
                       text.gp = gpar(), rect.gp = gpar(fill = "white"), vp = NULL) {
 
   if (length(label) != 1) {
-    abort("label must be of length 1")
+    cli::cli_abort("{.arg label} must be of length 1.")
   }
 
   if (!is.unit(x))
@@ -118,32 +126,42 @@ labelGrob <- function(label, x = unit(0.5, "npc"), y = unit(0.5, "npc"),
   if (!is.unit(y))
     y <- unit(y, default.units)
 
-  gTree(label = label, x = x, y = y, just = just, padding = padding, r = r,
-    name = name, text.gp = text.gp, rect.gp = rect.gp, vp = vp, cl = "labelgrob")
-}
+  if (!is.null(angle) & is.null(vp)) {
+    vp <- viewport(
+      angle = angle, x = x, y = y,
+      width = unit(0, "cm"), height = unit(0, "cm"),
+      gp = gpar(fontsize = text.gp$fontsize)
+    )
+    x <- unit(rep(0.5, length(x)), "npc")
+    y <- unit(rep(0.5, length(y)), "npc")
+  }
 
-#' @export
-makeContent.labelgrob <- function(x) {
-  hj <- resolveHJust(x$just, NULL)
-  vj <- resolveVJust(x$just, NULL)
+  descent <- font_descent(
+    text.gp$fontfamily, text.gp$fontface, text.gp$fontsize, text.gp$cex
+  )
+  # To balance labels, we ensure the top includes at least the descent height
+  # and subtract the descent height from the bottom padding
+  padding[1] <- unit.pmax(padding[1], descent)
+  padding[3] <- unit.pmax(padding[3] - descent, unit(0, "pt"))
 
-  t <- textGrob(
-    x$label,
-    x$x + 2 * (0.5 - hj) * x$padding,
-    x$y + 2 * (0.5 - vj) * x$padding,
-    just = c(hj, vj),
-    gp = x$text.gp,
-    name = "text"
+  hjust <- resolveHJust(just, NULL)
+  vjust <- resolveVJust(just, NULL)
+
+  text <- titleGrob(
+    label = label, hjust = hjust, vjust = vjust, x = x,
+    y = y + (1 - vjust) * descent,
+    margin = padding, margin_x = TRUE, margin_y = TRUE,
+    gp = text.gp
   )
 
-  r <- roundrectGrob(x$x, x$y, default.units = "native",
-    width = grobWidth(t) + 2 * x$padding,
-    height = grobHeight(t) + 2 * x$padding,
-    just = c(hj, vj),
-    r = x$r,
-    gp = x$rect.gp,
-    name = "box"
+  height <- heightDetails(text)
+  box <- roundrectGrob(
+    x = x, y = y + (0.5 - vjust) * height,
+    width  = widthDetails(text),
+    height = height,
+    just   = c(hjust, 0.5),
+    r = r, gp = rect.gp, name = "box"
   )
 
-  setChildren(x, gList(r, t))
+  gTree(children = gList(box, text), name = name, vp = vp)
 }
