@@ -32,6 +32,8 @@
 #' @param ... ignored.
 #' @export
 #' @family guides
+#' @seealso
+#' The `r link_book("legends section", "scales-colour#sec-guide-legend")`
 #' @examples
 #' \donttest{
 #' df <- expand.grid(X1 = 1:10, X2 = 1:10)
@@ -202,6 +204,7 @@ GuideLegend <- ggproto(
       cli::cli_warn("Duplicated {.arg override.aes} is ignored.")
     }
     params$override.aes <- params$override.aes[!duplicated(nms)]
+    params$aesthetic <- union(params$aesthetic, new_params$aesthetic)
 
     list(guide = self, params = params)
   },
@@ -647,10 +650,24 @@ keep_key_data <- function(key, data, aes, show) {
   for (column in match) {
     keep <- keep | key$.value %in% data[[column]]
   }
+
+  # NA might be included in breaks but originate from non-missing values that
+  # map to NA instead of *being* NA. We double-check if there are values
+  # outside the non-missing conventional limits.
+  is_na <- which(is.na(key$.value) & !keep)
+  if (length(is_na) > 0) {
+    na_keep <- FALSE
+    for (column in match) {
+      na_keep <- na_keep || !all(data[[column]] %in% key$.value)
+    }
+    keep[is_na] <- na_keep
+  }
+
   keep
 }
 
-position_margin <- function(position, margin = margin(), gap = unit(0, "pt")) {
+position_margin <- function(position, margin = NULL, gap = unit(0, "pt")) {
+  margin <- margin %||% margin()
   switch(
     position,
     top    = replace(margin, 3, margin[3] + gap),
@@ -770,7 +787,7 @@ deprecated_guide_args <- function(
 
   # Set as theme
   theme <- compact(theme)
-  if (!is.theme(theme)) {
+  if (!is_theme(theme)) {
     theme <- inject(theme(!!!theme))
   }
   theme
