@@ -105,6 +105,39 @@ ggtitle <- function(label, subtitle = waiver()) {
   labs(title = label, subtitle = subtitle)
 }
 
+#' @rdname labs
+#' @export
+#' @param plot A ggplot object
+#' @description
+#' `get_labs()` retrieves completed labels from a plot.
+get_labs <- function(plot = last_plot()) {
+  plot <- ggplot_build(plot)
+
+  labs <- plot$plot$labels
+
+  xy_labs <- rename(
+    c(x = plot$layout$resolve_label(plot$layout$panel_scales_x[[1]], labs),
+      y = plot$layout$resolve_label(plot$layout$panel_scales_y[[1]], labs)),
+    c(x.primary = "x", x.secondary = "x.sec",
+      y.primary = "y", y.secondary = "y.sec")
+  )
+
+  labs <- defaults(xy_labs, labs)
+
+  guides <- plot$plot$guides
+  if (length(guides$aesthetics) == 0) {
+    return(labs)
+  }
+
+  for (aes in guides$aesthetics) {
+    param <- guides$get_params(aes)
+    aes   <- param$aesthetic # Can have length > 1 when guide was merged
+    title <- vec_set_names(rep(list(param$title), length(aes)), aes)
+    labs  <- defaults(title, labs)
+  }
+  labs
+}
+
 #' Extract alt text from a plot
 #'
 #' This function returns a text that can be used as alt-text in webpages etc.
