@@ -1,6 +1,6 @@
 #' Nudge points a fixed distance
 #'
-#' `position_nudge` is generally useful for adjusting the position of
+#' `position_nudge()` is generally useful for adjusting the position of
 #' items on discrete scales by a small amount. Nudging is built in to
 #' [geom_text()] because it's so useful for moving labels a small
 #' distance from what they're labelling.
@@ -41,13 +41,22 @@ PositionNudge <- ggproto("PositionNudge", Position,
   x = 0,
   y = 0,
 
-  required_aes = c("x", "y"),
-
   setup_params = function(self, data) {
     list(x = self$x, y = self$y)
   },
 
-  compute_layer = function(data, params, panel) {
-    transform_position(data, function(x) x + params$x, function(y) y + params$y)
+  compute_layer = function(self, data, params, layout) {
+    # transform only the dimensions for which non-zero nudging is requested
+    if (any(params$x != 0)) {
+      if (any(params$y != 0)) {
+        transform_position(data, function(x) x + params$x, function(y) y + params$y)
+      } else {
+        transform_position(data, function(x) x + params$x, NULL)
+      }
+    } else if (any(params$y != 0)) {
+      transform_position(data, NULL, function(y) y + params$y)
+    } else {
+      data # if both x and y are 0 we don't need to transform
+    }
   }
 )
