@@ -21,6 +21,8 @@
 #'   a blank element among its parents will cause this element to be blank as
 #'   well. If `FALSE` any blank parent element will be ignored when
 #'   calculating final element state.
+#' @param type For testing elements: the type of element to expect. One of
+#'   `"blank"`, `"rect"`, `"line"` or `"text"`.
 #' @return An S3 object of class `element`, `rel`, or `margin`.
 #' @examples
 #' plot <- ggplot(mpg, aes(displ, hwy)) + geom_point()
@@ -144,6 +146,22 @@ element_text <- function(family = NULL, face = NULL, colour = NULL,
   )
 }
 
+#' @export
+#' @rdname element
+is_theme_element <- function(x, type = "any") {
+  switch(
+    type %||% "any",
+    any   = inherits(x, "element"),
+    rect  = inherits(x, "element_rect"),
+    line  = inherits(x, "element_line"),
+    text  = inherits(x, "element_text"),
+    blank = inherits(x, "element_blank"),
+    # TODO: ideally we accept more elements from extensions. We need to
+    # consider how this will work with S7 classes, where ggplot2 doesn't know
+    # about the extension's class objects.
+    FALSE
+  )
+}
 
 #' @export
 print.element <- function(x, ...) utils::str(x)
@@ -316,6 +334,8 @@ element_grob.element_line <- function(element, x = 0:1, y = 0:1,
 #'   inheritance relationship of the theme elements. The element tree must be provided as
 #'   a list of named element definitions created with el_def().
 #' @param complete If `TRUE` (the default), elements are set to inherit from blank elements.
+#' @seealso
+#' The `r link_book("defining theme elements section", "extensions#sec-defining-theme-elements")`
 #' @examples
 #' # Let's assume a package `ggxyz` wants to provide an easy way to add annotations to
 #' # plot panels. To do so, it registers a new theme element `ggxyz.panel.annotation`
@@ -618,7 +638,8 @@ validate_element <- function(el, elname, element_tree, call = caller_env()) {
   eldef <- element_tree[[elname]]
 
   if (is.null(eldef)) {
-    cli::cli_abort("The {.var {elname}} theme element is not defined in the element hierarchy.", call = call)
+    cli::cli_warn("The {.var {elname}} theme element is not defined in the element hierarchy.", call = call)
+    return()
   }
 
   # NULL values for elements are OK
